#xplat.tcl: utility shell routines for cross-platform applications. Execute appropriate platform-specific shell command for specified call.

#(c) 2015 Kevin Walzer/WordTech Communications LLC. License: standard Tcl license, http://www.tcl.tk/software/tcltk/license.html

package provide xplat 1.0

namespace eval xplat {

    #print text files: HTML and image files not supported
    proc print {filename} {

	switch [tk windowingsystem] {

	    "x11" {
		exec lpr [list $filename]
	    }
	    "win32" {
		eval exec [auto_execok start]  /min notepad /p [list $filename]
	    }
	    
	    "aqua" {
		package require cocoaprint
		cocoaprint::cocoaprint [list $filename] .
	    }
	}
    }


    #launch file with system default application
    proc launch {filename} {
	switch [tk windowingsystem] {

	    "x11" {
		exec xdg-open [list $filename]
	    }
	    "win32" {
		eval exec [auto_execok start] [list $filename]
	    }
	    
	    "aqua" {
		exec open $filename
	    }
	}
    }

    #keyboard accelerator key
    proc controlkey {} {
	
	switch [tk windowingsystem] {

	    "x11" {
		return "Control"
	    }
	    "win32" {
		return "Control"
	    }
	    
	    "aqua" {
		return "Command"
	    }   
	}
    }

    #system location for storing app data
    proc appconfig {appname} {

	set appdir ""
	switch [tk windowingsystem] {

	    "x11" {
		
		set appdir [file join $::env(HOME) "." [string tolower  "$appname"]]
	    }
	    "win32" {
		set appdir [file join $::env(APPDATA) "$appname"]
	    }
	    
	    "aqua" {
		set appdir [file join $::env(HOME) "Library" "Application Support" "$appname" "Preferences"]
	    }
	}
	if {![file exist $appdir]} {
	    file mkdir $appdir
	}
	return $appdir
    }

    #manipulate appeareance of app icon
    proc seticon {win imgpath} {
	switch [tk windowingsystem] {

	    "x11" {
		return [wm iconphoto $win $imgpath]
	    }
	    "win32" {
		return [wm iconphoto $win $imgpath]
	    }
	    
	    "aqua" {
		package require tkdock
		tkdock::switchIcon $imgpath
	    }   
	}
    }
    

    namespace export *

}





